@@ -4,7 +4,6 @@
 #define PyInt_AsLong PyLong_AsLong
 
 static PyObject *fitpack_error;
-#include "__fitpack.h"
 
 #ifdef HAVE_ILP64
 
@@ -28,8 +27,8 @@ static PyObject *fitpack_error;
 
 #else
 
-#define F_INT npy_int32
-#define F_INT_NPY NPY_INT32
+#define F_INT int
+#define F_INT_NPY NPY_INT
 #define F_INT_MAX NPY_MAX_INT32
 #if NPY_BITSOF_SHORT == 32
 #define F_INT_PYFMT   "h"
@@ -128,7 +127,6 @@ _mul_overflow_f_int(F_INT mx, F_INT my) {
 	#if defined(NO_APPEND_FORTRAN)
 	/* nothing to do */
 	#else
-		#define PERCUR PERCUR_
 		#define PARCUR PARCUR_
 		#define CLOCUR CLOCUR_
 		#define SURFIT SURFIT_
@@ -136,13 +134,11 @@ _mul_overflow_f_int(F_INT mx, F_INT my) {
 	#endif
 #else
 	#if defined(NO_APPEND_FORTRAN)
-		#define PERCUR percur
 		#define PARCUR parcur
 		#define CLOCUR clocur
 		#define SURFIT surfit
 		#define INSERT insert
 	#else
-		#define PERCUR percur_
 		#define PARCUR parcur_
 		#define CLOCUR clocur_
 		#define SURFIT surfit_
@@ -150,9 +146,6 @@ _mul_overflow_f_int(F_INT mx, F_INT my) {
 	#endif
 #endif
 
-void PERCUR(F_INT*,F_INT*,double*,double*,double*,F_INT*,
-        double*,F_INT*,F_INT*,double*,double*,double*,
-        double*,F_INT*,F_INT*,F_INT*);
 void PARCUR(F_INT*,F_INT*,F_INT*,F_INT*,double*,F_INT*,double*,
         double*,double*,double*,F_INT*,double*,F_INT*,F_INT*,
         double*,F_INT*,double*,double*,double*,F_INT*,F_INT*,F_INT*);
@@ -623,5 +616,9 @@ PyInit__fitpack(void)
         return NULL;
     }
 
+#if Py_GIL_DISABLED
+    PyUnstable_Module_SetGIL(module, Py_MOD_GIL_NOT_USED);
+#endif
+
     return module;
 }
